# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CenArgs', 'Cen']

@pulumi.input_type
class CenArgs:
    def __init__(__self__, *,
                 cen_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CenTagArgs']]]] = None):
        """
        The set of arguments for constructing a Cen resource.
        :param pulumi.Input[builtins.str] cen_name: CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        :param pulumi.Input[builtins.str] description: CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        :param pulumi.Input[builtins.str] project_name: CEN实例所属项目的名称。不填则默认为default。
        """
        if cen_name is not None:
            pulumi.set(__self__, "cen_name", cen_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="cenName")
    def cen_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        """
        return pulumi.get(self, "cen_name")

    @cen_name.setter
    def cen_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例所属项目的名称。不填则默认为default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CenTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CenTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CenState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 cen_bandwidth_package_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 cen_name: Optional[pulumi.Input[builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CenTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Cen resources.
        :param pulumi.Input[builtins.str] account_id: CEN实例所属的账号ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cen_bandwidth_package_ids: 带宽包ID。
        :param pulumi.Input[builtins.str] cen_id: CEN实例的ID。
        :param pulumi.Input[builtins.str] cen_name: CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        :param pulumi.Input[builtins.str] creation_time: 创建CEN实例的时间。
        :param pulumi.Input[builtins.str] description: CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        :param pulumi.Input[builtins.str] project_name: CEN实例所属项目的名称。不填则默认为default。
        :param pulumi.Input[builtins.str] status: CEN实例的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        :param pulumi.Input[builtins.str] update_time: 更新CEN实例的时间。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if cen_bandwidth_package_ids is not None:
            pulumi.set(__self__, "cen_bandwidth_package_ids", cen_bandwidth_package_ids)
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if cen_name is not None:
            pulumi.set(__self__, "cen_name", cen_name)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="cenBandwidthPackageIds")
    def cen_bandwidth_package_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        带宽包ID。
        """
        return pulumi.get(self, "cen_bandwidth_package_ids")

    @cen_bandwidth_package_ids.setter
    def cen_bandwidth_package_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "cen_bandwidth_package_ids", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例的ID。
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="cenName")
    def cen_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        """
        return pulumi.get(self, "cen_name")

    @cen_name.setter
    def cen_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_name", value)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建CEN实例的时间。
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例所属项目的名称。不填则默认为default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CEN实例的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CenTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CenTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新CEN实例的时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("bytepluscc:cen/cen:Cen")
class Cen(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CenTagArgs', 'CenTagArgsDict']]]]] = None,
                 __props__=None):
        """
        云企业网（Cloud Enterprise Network，CEN）提供一种能够快速构建跨地域私有网络（VPC）与云下数据中心（IDC）之间高速、优质、稳定的网络能力，帮助您打造一张具有企业级规模和通信能力的全球云上网络。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_encen_demo = bytepluscc.cen.Cen("CENCENDemo",
            cen_name="CENCENDemo",
            description="CENCENDemo descripiton",
            project_name="iac",
            tags=[{
                "key": "dev",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cen/cen:Cen example "cen_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cen_name: CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        :param pulumi.Input[builtins.str] description: CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        :param pulumi.Input[builtins.str] project_name: CEN实例所属项目的名称。不填则默认为default。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CenArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        云企业网（Cloud Enterprise Network，CEN）提供一种能够快速构建跨地域私有网络（VPC）与云下数据中心（IDC）之间高速、优质、稳定的网络能力，帮助您打造一张具有企业级规模和通信能力的全球云上网络。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_encen_demo = bytepluscc.cen.Cen("CENCENDemo",
            cen_name="CENCENDemo",
            description="CENCENDemo descripiton",
            project_name="iac",
            tags=[{
                "key": "dev",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cen/cen:Cen example "cen_id"
        ```

        :param str resource_name: The name of the resource.
        :param CenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CenTagArgs', 'CenTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CenArgs.__new__(CenArgs)

            __props__.__dict__["cen_name"] = cen_name
            __props__.__dict__["description"] = description
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["account_id"] = None
            __props__.__dict__["cen_bandwidth_package_ids"] = None
            __props__.__dict__["cen_id"] = None
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
        super(Cen, __self__).__init__(
            'bytepluscc:cen/cen:Cen',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            cen_bandwidth_package_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            cen_id: Optional[pulumi.Input[builtins.str]] = None,
            cen_name: Optional[pulumi.Input[builtins.str]] = None,
            creation_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CenTagArgs', 'CenTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Cen':
        """
        Get an existing Cen resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: CEN实例所属的账号ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cen_bandwidth_package_ids: 带宽包ID。
        :param pulumi.Input[builtins.str] cen_id: CEN实例的ID。
        :param pulumi.Input[builtins.str] cen_name: CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        :param pulumi.Input[builtins.str] creation_time: 创建CEN实例的时间。
        :param pulumi.Input[builtins.str] description: CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        :param pulumi.Input[builtins.str] project_name: CEN实例所属项目的名称。不填则默认为default。
        :param pulumi.Input[builtins.str] status: CEN实例的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        :param pulumi.Input[builtins.str] update_time: 更新CEN实例的时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CenState.__new__(_CenState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["cen_bandwidth_package_ids"] = cen_bandwidth_package_ids
        __props__.__dict__["cen_id"] = cen_id
        __props__.__dict__["cen_name"] = cen_name
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["description"] = description
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        return Cen(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        CEN实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="cenBandwidthPackageIds")
    def cen_bandwidth_package_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        带宽包ID。
        """
        return pulumi.get(self, "cen_bandwidth_package_ids")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Output[builtins.str]:
        """
        CEN实例的ID。
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="cenName")
    def cen_name(self) -> pulumi.Output[builtins.str]:
        """
        CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        """
        return pulumi.get(self, "cen_name")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[builtins.str]:
        """
        创建CEN实例的时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        CEN实例所属项目的名称。不填则默认为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        CEN实例的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.CenTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        更新CEN实例的时间。
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetScalingConfigurationResult',
    'AwaitableGetScalingConfigurationResult',
    'get_scaling_configuration',
    'get_scaling_configuration_output',
]

@pulumi.output_type
class GetScalingConfigurationResult:
    """
    A collection of values returned by getScalingConfiguration.
    """
    def __init__(__self__, created_at=None, eip=None, host_name=None, hpc_cluster_id=None, id=None, image_id=None, instance_charge_type=None, instance_description=None, instance_name=None, instance_type_overrides=None, instance_types=None, ipv6_address_count=None, key_pair_name=None, lifecycle_state=None, password=None, project_name=None, scaling_configuration_id=None, scaling_configuration_name=None, scaling_group_id=None, security_enhancement_strategy=None, security_group_ids=None, spot_strategy=None, tags=None, updated_at=None, user_data=None, volumes=None, zone_id=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if eip and not isinstance(eip, dict):
            raise TypeError("Expected argument 'eip' to be a dict")
        pulumi.set(__self__, "eip", eip)
        if host_name and not isinstance(host_name, str):
            raise TypeError("Expected argument 'host_name' to be a str")
        pulumi.set(__self__, "host_name", host_name)
        if hpc_cluster_id and not isinstance(hpc_cluster_id, str):
            raise TypeError("Expected argument 'hpc_cluster_id' to be a str")
        pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if instance_charge_type and not isinstance(instance_charge_type, str):
            raise TypeError("Expected argument 'instance_charge_type' to be a str")
        pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_description and not isinstance(instance_description, str):
            raise TypeError("Expected argument 'instance_description' to be a str")
        pulumi.set(__self__, "instance_description", instance_description)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_type_overrides and not isinstance(instance_type_overrides, list):
            raise TypeError("Expected argument 'instance_type_overrides' to be a list")
        pulumi.set(__self__, "instance_type_overrides", instance_type_overrides)
        if instance_types and not isinstance(instance_types, list):
            raise TypeError("Expected argument 'instance_types' to be a list")
        pulumi.set(__self__, "instance_types", instance_types)
        if ipv6_address_count and not isinstance(ipv6_address_count, int):
            raise TypeError("Expected argument 'ipv6_address_count' to be a int")
        pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if key_pair_name and not isinstance(key_pair_name, str):
            raise TypeError("Expected argument 'key_pair_name' to be a str")
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        if lifecycle_state and not isinstance(lifecycle_state, str):
            raise TypeError("Expected argument 'lifecycle_state' to be a str")
        pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if scaling_configuration_id and not isinstance(scaling_configuration_id, str):
            raise TypeError("Expected argument 'scaling_configuration_id' to be a str")
        pulumi.set(__self__, "scaling_configuration_id", scaling_configuration_id)
        if scaling_configuration_name and not isinstance(scaling_configuration_name, str):
            raise TypeError("Expected argument 'scaling_configuration_name' to be a str")
        pulumi.set(__self__, "scaling_configuration_name", scaling_configuration_name)
        if scaling_group_id and not isinstance(scaling_group_id, str):
            raise TypeError("Expected argument 'scaling_group_id' to be a str")
        pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if security_enhancement_strategy and not isinstance(security_enhancement_strategy, str):
            raise TypeError("Expected argument 'security_enhancement_strategy' to be a str")
        pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)
        if security_group_ids and not isinstance(security_group_ids, list):
            raise TypeError("Expected argument 'security_group_ids' to be a list")
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        if spot_strategy and not isinstance(spot_strategy, str):
            raise TypeError("Expected argument 'spot_strategy' to be a str")
        pulumi.set(__self__, "spot_strategy", spot_strategy)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if user_data and not isinstance(user_data, str):
            raise TypeError("Expected argument 'user_data' to be a str")
        pulumi.set(__self__, "user_data", user_data)
        if volumes and not isinstance(volumes, list):
            raise TypeError("Expected argument 'volumes' to be a list")
        pulumi.set(__self__, "volumes", volumes)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        资源创建时间(UTC时间)
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def eip(self) -> 'outputs.GetScalingConfigurationEipResult':
        """
        公网IP。
        """
        return pulumi.get(self, "eip")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> builtins.str:
        """
        实例的主机名。取值：Linux实例允许使用点号分隔字符成多段，每段中允许使用字母、数字或中划线“-”。不能以点号“.”或中划线“-”开头或结尾，且不能连续使用点号“.”或中划线“-”。Linux系统的主机名长度限制为2～63个字符。Windows实例允许使用字母、数字或中划线“-”，不能完全是数字。不能以中划线“-”开头或结尾，且不能连续使用中划线“-”。Windows系统的主机名长度限制在2～15个字符。如不填，则遵循以下规则自动生成：结构：iv  - + 初始主机名，例如iv-3tigy72q3u3vj0******。已创建实例保持原主机名生成逻辑，不随实例重启发生变化。初始主机名生成逻辑：Linux：提取实例IDi-之后的全部字符。Windows：提取实例IDi-之后的后12位字符。
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> builtins.str:
        """
        实例所属的高性能计算集群的ID。仅当InstanceTypes.N指定为“高性能计算GPU型”时有效。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        镜像ID，伸缩组自动创建实例时使用的镜像资源。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> builtins.str:
        """
        实例计费类型。取值：PrePaid（包年包月）/PostPaid（按量付费）
        """
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> builtins.str:
        """
        实例的描述，取值：不能以数字、中划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制在0 ~ 255之间。不填默认为空字符串。
        """
        return pulumi.get(self, "instance_description")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例的名称，取值：以字母或中文开头。只能包含中文、字母、数字、下划线“_”、中划线“-”和点号“.”。长度限制为1～128个字符。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceTypeOverrides")
    def instance_type_overrides(self) -> Sequence['outputs.GetScalingConfigurationInstanceTypeOverrideResult']:
        return pulumi.get(self, "instance_type_overrides")

    @property
    @pulumi.getter(name="instanceTypes")
    def instance_types(self) -> Sequence[builtins.str]:
        """
        实例的计算规格列表。
        """
        return pulumi.get(self, "instance_types")

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> builtins.int:
        """
        是否为实例网卡分配IPv6地址。取值：0：不分配IPv6地址。1：分配IPv6地址，系统自动为您分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> builtins.str:
        """
        KeyPairName string 可选 示例值：kp-test-123，使用“SSH密钥对”登录实例时，请输入密钥对的名称。如果同时设置了KeyPairName和Password，则仅生效KeyPairName。
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> builtins.str:
        """
        生命周期状态。取值：Active（活跃）/InActive（非活跃）
        """
        return pulumi.get(self, "lifecycle_state")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        使用“密码”方式登录实例时，请设置root登录密码：长度限制在8～30之间，密码只能由大写字母、小写字母、数字和特殊字符组成，且必须包含至少三项，特殊字符可以使用：`~!#$%^&*()_-+= |，不能以“/”和“$6$”开头
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        伸缩配置创建的实例所属项目，默认为空。一个资源只能归属于一个项目。
        只能包含字母、数字、下划线“_”、点“.”和中划线“-”。
        长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="scalingConfigurationId")
    def scaling_configuration_id(self) -> builtins.str:
        """
        伸缩配置ID。
        """
        return pulumi.get(self, "scaling_configuration_id")

    @property
    @pulumi.getter(name="scalingConfigurationName")
    def scaling_configuration_name(self) -> builtins.str:
        """
        伸缩配置的名称，在同一地域下同一伸缩组内伸缩配置名称唯一。取值:只能以中文、字母开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_configuration_name")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> builtins.str:
        """
        伸缩配置所属的伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> builtins.str:
        """
        是否开启安全加固，取值：Active：开启安全加固，仅对公共镜像生效。InActive：关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[builtins.str]:
        """
        实例主网卡关联的安全组ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> builtins.str:
        """
        实例的抢占策略。取值：NoSpot（默认）：表示创建正常按量付费实例。SpotAsPriceGo：表示系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：表示需要设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetScalingConfigurationTagResult']:
        """
        标签键值对。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        资源更新时间(UTC时间)
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> builtins.str:
        """
        实例自定义数据。设置的自定义数据必须经过Base64编码，且Base64编码前的自定义数据大小不能超过16KB。不填则默认为空。
        """
        return pulumi.get(self, "user_data")

    @property
    @pulumi.getter
    def volumes(self) -> Sequence['outputs.GetScalingConfigurationVolumeResult']:
        """
        云盘。
        """
        return pulumi.get(self, "volumes")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        伸缩配置可用区ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetScalingConfigurationResult(GetScalingConfigurationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetScalingConfigurationResult(
            created_at=self.created_at,
            eip=self.eip,
            host_name=self.host_name,
            hpc_cluster_id=self.hpc_cluster_id,
            id=self.id,
            image_id=self.image_id,
            instance_charge_type=self.instance_charge_type,
            instance_description=self.instance_description,
            instance_name=self.instance_name,
            instance_type_overrides=self.instance_type_overrides,
            instance_types=self.instance_types,
            ipv6_address_count=self.ipv6_address_count,
            key_pair_name=self.key_pair_name,
            lifecycle_state=self.lifecycle_state,
            password=self.password,
            project_name=self.project_name,
            scaling_configuration_id=self.scaling_configuration_id,
            scaling_configuration_name=self.scaling_configuration_name,
            scaling_group_id=self.scaling_group_id,
            security_enhancement_strategy=self.security_enhancement_strategy,
            security_group_ids=self.security_group_ids,
            spot_strategy=self.spot_strategy,
            tags=self.tags,
            updated_at=self.updated_at,
            user_data=self.user_data,
            volumes=self.volumes,
            zone_id=self.zone_id)


def get_scaling_configuration(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetScalingConfigurationResult:
    """
    Data Source schema for Byteplus::AutoScaling::ScalingConfiguration


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:autoscaling/getScalingConfiguration:getScalingConfiguration', __args__, opts=opts, typ=GetScalingConfigurationResult).value

    return AwaitableGetScalingConfigurationResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        eip=pulumi.get(__ret__, 'eip'),
        host_name=pulumi.get(__ret__, 'host_name'),
        hpc_cluster_id=pulumi.get(__ret__, 'hpc_cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        instance_charge_type=pulumi.get(__ret__, 'instance_charge_type'),
        instance_description=pulumi.get(__ret__, 'instance_description'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_type_overrides=pulumi.get(__ret__, 'instance_type_overrides'),
        instance_types=pulumi.get(__ret__, 'instance_types'),
        ipv6_address_count=pulumi.get(__ret__, 'ipv6_address_count'),
        key_pair_name=pulumi.get(__ret__, 'key_pair_name'),
        lifecycle_state=pulumi.get(__ret__, 'lifecycle_state'),
        password=pulumi.get(__ret__, 'password'),
        project_name=pulumi.get(__ret__, 'project_name'),
        scaling_configuration_id=pulumi.get(__ret__, 'scaling_configuration_id'),
        scaling_configuration_name=pulumi.get(__ret__, 'scaling_configuration_name'),
        scaling_group_id=pulumi.get(__ret__, 'scaling_group_id'),
        security_enhancement_strategy=pulumi.get(__ret__, 'security_enhancement_strategy'),
        security_group_ids=pulumi.get(__ret__, 'security_group_ids'),
        spot_strategy=pulumi.get(__ret__, 'spot_strategy'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        user_data=pulumi.get(__ret__, 'user_data'),
        volumes=pulumi.get(__ret__, 'volumes'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_scaling_configuration_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetScalingConfigurationResult]:
    """
    Data Source schema for Byteplus::AutoScaling::ScalingConfiguration


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:autoscaling/getScalingConfiguration:getScalingConfiguration', __args__, opts=opts, typ=GetScalingConfigurationResult)
    return __ret__.apply(lambda __response__: GetScalingConfigurationResult(
        created_at=pulumi.get(__response__, 'created_at'),
        eip=pulumi.get(__response__, 'eip'),
        host_name=pulumi.get(__response__, 'host_name'),
        hpc_cluster_id=pulumi.get(__response__, 'hpc_cluster_id'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        instance_charge_type=pulumi.get(__response__, 'instance_charge_type'),
        instance_description=pulumi.get(__response__, 'instance_description'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_type_overrides=pulumi.get(__response__, 'instance_type_overrides'),
        instance_types=pulumi.get(__response__, 'instance_types'),
        ipv6_address_count=pulumi.get(__response__, 'ipv6_address_count'),
        key_pair_name=pulumi.get(__response__, 'key_pair_name'),
        lifecycle_state=pulumi.get(__response__, 'lifecycle_state'),
        password=pulumi.get(__response__, 'password'),
        project_name=pulumi.get(__response__, 'project_name'),
        scaling_configuration_id=pulumi.get(__response__, 'scaling_configuration_id'),
        scaling_configuration_name=pulumi.get(__response__, 'scaling_configuration_name'),
        scaling_group_id=pulumi.get(__response__, 'scaling_group_id'),
        security_enhancement_strategy=pulumi.get(__response__, 'security_enhancement_strategy'),
        security_group_ids=pulumi.get(__response__, 'security_group_ids'),
        spot_strategy=pulumi.get(__response__, 'spot_strategy'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        user_data=pulumi.get(__response__, 'user_data'),
        volumes=pulumi.get(__response__, 'volumes'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AddonArgs', 'Addon']

@pulumi.input_type
class AddonArgs:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 config: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_node_type: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input['AddonStatusArgs']] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Addon resource.
        :param pulumi.Input[builtins.str] cluster_id: 组件所在集群 ID。
        :param pulumi.Input[builtins.str] config: 组件配置。
        :param pulumi.Input[builtins.str] deploy_mode: 组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        :param pulumi.Input[builtins.str] deploy_node_type: 部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        :param pulumi.Input[builtins.str] name: 组件名称。
        :param pulumi.Input['AddonStatusArgs'] status: 组件状态。
        :param pulumi.Input[builtins.str] version: 组件版本。
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if deploy_mode is not None:
            pulumi.set(__self__, "deploy_mode", deploy_mode)
        if deploy_node_type is not None:
            pulumi.set(__self__, "deploy_node_type", deploy_node_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件所在集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件配置。
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        """
        return pulumi.get(self, "deploy_mode")

    @deploy_mode.setter
    def deploy_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deploy_mode", value)

    @property
    @pulumi.getter(name="deployNodeType")
    def deploy_node_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        """
        return pulumi.get(self, "deploy_node_type")

    @deploy_node_type.setter
    def deploy_node_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deploy_node_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['AddonStatusArgs']]:
        """
        组件状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['AddonStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _AddonState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 config: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_node_type: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input['AddonStatusArgs']] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Addon resources.
        :param pulumi.Input[builtins.str] cluster_id: 组件所在集群 ID。
        :param pulumi.Input[builtins.str] config: 组件配置。
        :param pulumi.Input[builtins.str] created_time: 安装组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.str] deploy_mode: 组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        :param pulumi.Input[builtins.str] deploy_node_type: 部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        :param pulumi.Input[builtins.str] name: 组件名称。
        :param pulumi.Input['AddonStatusArgs'] status: 组件状态。
        :param pulumi.Input[builtins.str] updated_time: 更新组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.str] version: 组件版本。
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if deploy_mode is not None:
            pulumi.set(__self__, "deploy_mode", deploy_mode)
        if deploy_node_type is not None:
            pulumi.set(__self__, "deploy_node_type", deploy_node_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件所在集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件配置。
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安装组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        """
        return pulumi.get(self, "deploy_mode")

    @deploy_mode.setter
    def deploy_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deploy_mode", value)

    @property
    @pulumi.getter(name="deployNodeType")
    def deploy_node_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        """
        return pulumi.get(self, "deploy_node_type")

    @deploy_node_type.setter
    def deploy_node_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deploy_node_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['AddonStatusArgs']]:
        """
        组件状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['AddonStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组件版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("bytepluscc:vke/addon:Addon")
class Addon(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 config: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_node_type: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[Union['AddonStatusArgs', 'AddonStatusArgsDict']]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        集群中支持安装多种类型的组件，包括 网络、存储、监控、DNS、安全、镜像、GPU 等，满足您多种业务场景需求。您可按需部署、升级或卸载组件。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_ke_addon_demo = bytepluscc.vke.Addon("VKEAddonDemo",
            cluster_id="cd35mtki***",
            deploy_mode="Unmanaged",
            deploy_node_type="Node",
            name="csi-nas",
            version="v1.2.7",
            config="{\\"CsiNasDriver\\":{\\"Resources\\":{\\"Requests\\":{\\"Cpu\\":\\"0.01\\",\\"Memory\\":\\"20Mi\\"},\\"Limits\\":{\\"Cpu\\":\\"0.9\\",\\"Memory\\":\\"1900Mi\\"}}},\\"CsiProvisioner\\":{\\"Resources\\":{\\"Requests\\":{\\"Cpu\\":\\"0.01\\",\\"Memory\\":\\"20Mi\\"},\\"Limits\\":{\\"Cpu\\":\\"0.5\\",\\"Memory\\":\\"4Gi\\"}}},\\"LivenessProbe\\":{\\"Resources\\":{\\"Requests\\":{\\"Cpu\\":\\"0.01\\",\\"Memory\\":\\"20Mi\\"},\\"Limits\\":{\\"Cpu\\":\\"0.1\\",\\"Memory\\":\\"100Mi\\"}}}}")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/addon:Addon example "cluster_id|name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: 组件所在集群 ID。
        :param pulumi.Input[builtins.str] config: 组件配置。
        :param pulumi.Input[builtins.str] deploy_mode: 组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        :param pulumi.Input[builtins.str] deploy_node_type: 部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        :param pulumi.Input[builtins.str] name: 组件名称。
        :param pulumi.Input[Union['AddonStatusArgs', 'AddonStatusArgsDict']] status: 组件状态。
        :param pulumi.Input[builtins.str] version: 组件版本。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AddonArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        集群中支持安装多种类型的组件，包括 网络、存储、监控、DNS、安全、镜像、GPU 等，满足您多种业务场景需求。您可按需部署、升级或卸载组件。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_ke_addon_demo = bytepluscc.vke.Addon("VKEAddonDemo",
            cluster_id="cd35mtki***",
            deploy_mode="Unmanaged",
            deploy_node_type="Node",
            name="csi-nas",
            version="v1.2.7",
            config="{\\"CsiNasDriver\\":{\\"Resources\\":{\\"Requests\\":{\\"Cpu\\":\\"0.01\\",\\"Memory\\":\\"20Mi\\"},\\"Limits\\":{\\"Cpu\\":\\"0.9\\",\\"Memory\\":\\"1900Mi\\"}}},\\"CsiProvisioner\\":{\\"Resources\\":{\\"Requests\\":{\\"Cpu\\":\\"0.01\\",\\"Memory\\":\\"20Mi\\"},\\"Limits\\":{\\"Cpu\\":\\"0.5\\",\\"Memory\\":\\"4Gi\\"}}},\\"LivenessProbe\\":{\\"Resources\\":{\\"Requests\\":{\\"Cpu\\":\\"0.01\\",\\"Memory\\":\\"20Mi\\"},\\"Limits\\":{\\"Cpu\\":\\"0.1\\",\\"Memory\\":\\"100Mi\\"}}}}")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/addon:Addon example "cluster_id|name"
        ```

        :param str resource_name: The name of the resource.
        :param AddonArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AddonArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 config: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 deploy_node_type: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[Union['AddonStatusArgs', 'AddonStatusArgsDict']]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AddonArgs.__new__(AddonArgs)

            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["config"] = config
            __props__.__dict__["deploy_mode"] = deploy_mode
            __props__.__dict__["deploy_node_type"] = deploy_node_type
            __props__.__dict__["name"] = name
            __props__.__dict__["status"] = status
            __props__.__dict__["version"] = version
            __props__.__dict__["created_time"] = None
            __props__.__dict__["updated_time"] = None
        super(Addon, __self__).__init__(
            'bytepluscc:vke/addon:Addon',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            config: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            deploy_mode: Optional[pulumi.Input[builtins.str]] = None,
            deploy_node_type: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[Union['AddonStatusArgs', 'AddonStatusArgsDict']]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None) -> 'Addon':
        """
        Get an existing Addon resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: 组件所在集群 ID。
        :param pulumi.Input[builtins.str] config: 组件配置。
        :param pulumi.Input[builtins.str] created_time: 安装组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.str] deploy_mode: 组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        :param pulumi.Input[builtins.str] deploy_node_type: 部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        :param pulumi.Input[builtins.str] name: 组件名称。
        :param pulumi.Input[Union['AddonStatusArgs', 'AddonStatusArgsDict']] status: 组件状态。
        :param pulumi.Input[builtins.str] updated_time: 更新组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.str] version: 组件版本。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AddonState.__new__(_AddonState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["config"] = config
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["deploy_mode"] = deploy_mode
        __props__.__dict__["deploy_node_type"] = deploy_node_type
        __props__.__dict__["name"] = name
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["version"] = version
        return Addon(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        组件所在集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[builtins.str]:
        """
        组件配置。
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        安装组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> pulumi.Output[builtins.str]:
        """
        组件部署模式，取值：Unmanaged：非托管模式部署。Managed：托管模式部署。
        """
        return pulumi.get(self, "deploy_mode")

    @property
    @pulumi.getter(name="deployNodeType")
    def deploy_node_type(self) -> pulumi.Output[builtins.str]:
        """
        部署节点的类型。仅DeployModes=Unmanaged时，才需要指定该参数。取值：Node：以节点方式部署。VirtualNode：以虚拟节点方式部署。
        """
        return pulumi.get(self, "deploy_node_type")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        组件名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.AddonStatus']:
        """
        组件状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新组件的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        组件版本。
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PermissionArgs', 'Permission']

@pulumi.input_type
class PermissionArgs:
    def __init__(__self__, *,
                 authorizer_id: Optional[pulumi.Input[builtins.int]] = None,
                 authorizer_type: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 grantee_id: Optional[pulumi.Input[builtins.int]] = None,
                 grantee_type: Optional[pulumi.Input[builtins.str]] = None,
                 is_custom_role: Optional[pulumi.Input[builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 role_domain: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Permission resource.
        :param pulumi.Input[builtins.int] authorizer_id: 授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] authorizer_type: 授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.str] cluster_id: 需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        :param pulumi.Input[builtins.int] grantee_id: 被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] grantee_type: 被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.bool] is_custom_role: 给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        :param pulumi.Input[builtins.str] namespace: 需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        :param pulumi.Input[builtins.str] role_domain: 为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        :param pulumi.Input[builtins.str] role_name: 给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        """
        if authorizer_id is not None:
            pulumi.set(__self__, "authorizer_id", authorizer_id)
        if authorizer_type is not None:
            pulumi.set(__self__, "authorizer_type", authorizer_type)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if grantee_id is not None:
            pulumi.set(__self__, "grantee_id", grantee_id)
        if grantee_type is not None:
            pulumi.set(__self__, "grantee_type", grantee_type)
        if is_custom_role is not None:
            pulumi.set(__self__, "is_custom_role", is_custom_role)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if role_domain is not None:
            pulumi.set(__self__, "role_domain", role_domain)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter(name="authorizerId")
    def authorizer_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        """
        return pulumi.get(self, "authorizer_id")

    @authorizer_id.setter
    def authorizer_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "authorizer_id", value)

    @property
    @pulumi.getter(name="authorizerType")
    def authorizer_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        """
        return pulumi.get(self, "authorizer_type")

    @authorizer_type.setter
    def authorizer_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorizer_type", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="granteeId")
    def grantee_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        """
        return pulumi.get(self, "grantee_id")

    @grantee_id.setter
    def grantee_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "grantee_id", value)

    @property
    @pulumi.getter(name="granteeType")
    def grantee_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        """
        return pulumi.get(self, "grantee_type")

    @grantee_type.setter
    def grantee_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grantee_type", value)

    @property
    @pulumi.getter(name="isCustomRole")
    def is_custom_role(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        """
        return pulumi.get(self, "is_custom_role")

    @is_custom_role.setter
    def is_custom_role(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_custom_role", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="roleDomain")
    def role_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        """
        return pulumi.get(self, "role_domain")

    @role_domain.setter
    def role_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_domain", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)


@pulumi.input_type
class _PermissionState:
    def __init__(__self__, *,
                 authorized_at: Optional[pulumi.Input[builtins.str]] = None,
                 authorizer_id: Optional[pulumi.Input[builtins.int]] = None,
                 authorizer_name: Optional[pulumi.Input[builtins.str]] = None,
                 authorizer_type: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 grantee_id: Optional[pulumi.Input[builtins.int]] = None,
                 grantee_type: Optional[pulumi.Input[builtins.str]] = None,
                 is_custom_role: Optional[pulumi.Input[builtins.bool]] = None,
                 kube_role_binding_name: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 permission_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_selector: Optional[pulumi.Input[builtins.str]] = None,
                 revoked_at: Optional[pulumi.Input[builtins.str]] = None,
                 role_domain: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Permission resources.
        :param pulumi.Input[builtins.str] authorized_at: RBAC 权限策略资源被授权的时间。
        :param pulumi.Input[builtins.int] authorizer_id: 授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] authorizer_name: 授权者名称
        :param pulumi.Input[builtins.str] authorizer_type: 授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.str] cluster_id: 需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        :param pulumi.Input[builtins.str] created_time: RBAC 权限策略资源创建的时间。
        :param pulumi.Input[builtins.int] grantee_id: 被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] grantee_type: 被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.bool] is_custom_role: 给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        :param pulumi.Input[builtins.str] kube_role_binding_name: RBAC 权限策略资源在 Kubernetes 中的对象名称。
        :param pulumi.Input[builtins.str] message: 授权详细消息。
        :param pulumi.Input[builtins.str] namespace: 需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        :param pulumi.Input[builtins.str] permission_id: RBAC 权限策略资源 ID。
        :param pulumi.Input[builtins.str] project_selector: 项目选择器
        :param pulumi.Input[builtins.str] revoked_at: 撤销授权的时间。
        :param pulumi.Input[builtins.str] role_domain: 为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        :param pulumi.Input[builtins.str] role_name: 给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        :param pulumi.Input[builtins.str] status: RBAC 权限访问策略资源的状态，取值如下：Success：授权成功。Failed：授权失败。Pending：授权中。PartialSuccess：部分授权成功。
        """
        if authorized_at is not None:
            pulumi.set(__self__, "authorized_at", authorized_at)
        if authorizer_id is not None:
            pulumi.set(__self__, "authorizer_id", authorizer_id)
        if authorizer_name is not None:
            pulumi.set(__self__, "authorizer_name", authorizer_name)
        if authorizer_type is not None:
            pulumi.set(__self__, "authorizer_type", authorizer_type)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if grantee_id is not None:
            pulumi.set(__self__, "grantee_id", grantee_id)
        if grantee_type is not None:
            pulumi.set(__self__, "grantee_type", grantee_type)
        if is_custom_role is not None:
            pulumi.set(__self__, "is_custom_role", is_custom_role)
        if kube_role_binding_name is not None:
            pulumi.set(__self__, "kube_role_binding_name", kube_role_binding_name)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if permission_id is not None:
            pulumi.set(__self__, "permission_id", permission_id)
        if project_selector is not None:
            pulumi.set(__self__, "project_selector", project_selector)
        if revoked_at is not None:
            pulumi.set(__self__, "revoked_at", revoked_at)
        if role_domain is not None:
            pulumi.set(__self__, "role_domain", role_domain)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="authorizedAt")
    def authorized_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RBAC 权限策略资源被授权的时间。
        """
        return pulumi.get(self, "authorized_at")

    @authorized_at.setter
    def authorized_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorized_at", value)

    @property
    @pulumi.getter(name="authorizerId")
    def authorizer_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        """
        return pulumi.get(self, "authorizer_id")

    @authorizer_id.setter
    def authorizer_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "authorizer_id", value)

    @property
    @pulumi.getter(name="authorizerName")
    def authorizer_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        授权者名称
        """
        return pulumi.get(self, "authorizer_name")

    @authorizer_name.setter
    def authorizer_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorizer_name", value)

    @property
    @pulumi.getter(name="authorizerType")
    def authorizer_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        """
        return pulumi.get(self, "authorizer_type")

    @authorizer_type.setter
    def authorizer_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorizer_type", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RBAC 权限策略资源创建的时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="granteeId")
    def grantee_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        """
        return pulumi.get(self, "grantee_id")

    @grantee_id.setter
    def grantee_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "grantee_id", value)

    @property
    @pulumi.getter(name="granteeType")
    def grantee_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        """
        return pulumi.get(self, "grantee_type")

    @grantee_type.setter
    def grantee_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grantee_type", value)

    @property
    @pulumi.getter(name="isCustomRole")
    def is_custom_role(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        """
        return pulumi.get(self, "is_custom_role")

    @is_custom_role.setter
    def is_custom_role(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_custom_role", value)

    @property
    @pulumi.getter(name="kubeRoleBindingName")
    def kube_role_binding_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RBAC 权限策略资源在 Kubernetes 中的对象名称。
        """
        return pulumi.get(self, "kube_role_binding_name")

    @kube_role_binding_name.setter
    def kube_role_binding_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kube_role_binding_name", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        授权详细消息。
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="permissionId")
    def permission_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RBAC 权限策略资源 ID。
        """
        return pulumi.get(self, "permission_id")

    @permission_id.setter
    def permission_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_id", value)

    @property
    @pulumi.getter(name="projectSelector")
    def project_selector(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目选择器
        """
        return pulumi.get(self, "project_selector")

    @project_selector.setter
    def project_selector(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_selector", value)

    @property
    @pulumi.getter(name="revokedAt")
    def revoked_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        撤销授权的时间。
        """
        return pulumi.get(self, "revoked_at")

    @revoked_at.setter
    def revoked_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "revoked_at", value)

    @property
    @pulumi.getter(name="roleDomain")
    def role_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        """
        return pulumi.get(self, "role_domain")

    @role_domain.setter
    def role_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_domain", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RBAC 权限访问策略资源的状态，取值如下：Success：授权成功。Failed：授权失败。Pending：授权中。PartialSuccess：部分授权成功。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("bytepluscc:vke/permission:Permission")
class Permission(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorizer_id: Optional[pulumi.Input[builtins.int]] = None,
                 authorizer_type: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 grantee_id: Optional[pulumi.Input[builtins.int]] = None,
                 grantee_type: Optional[pulumi.Input[builtins.str]] = None,
                 is_custom_role: Optional[pulumi.Input[builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 role_domain: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        容器服务提供集群 RBAC 授权功能，为 IAM 用户或角色授予 RBAC 访问权限，包括可访问的资源、权限的作用范围、预置的角色类型等，从而更好地管理集群的安全访问控制，满足企业用户细粒度的资源访问权限控制需求。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_ke_permission_demo = bytepluscc.vke.Permission("VKEPermissionDemo",
            role_domain="namespace",
            cluster_id="cd48m3cb1b2ba7l6ebgp0xxxxx",
            namespace="kube-public",
            role_name="vke:visitor",
            is_custom_role=False,
            grantee_id=59433888,
            grantee_type="User")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/permission:Permission example "permission_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] authorizer_id: 授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] authorizer_type: 授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.str] cluster_id: 需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        :param pulumi.Input[builtins.int] grantee_id: 被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] grantee_type: 被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.bool] is_custom_role: 给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        :param pulumi.Input[builtins.str] namespace: 需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        :param pulumi.Input[builtins.str] role_domain: 为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        :param pulumi.Input[builtins.str] role_name: 给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PermissionArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        容器服务提供集群 RBAC 授权功能，为 IAM 用户或角色授予 RBAC 访问权限，包括可访问的资源、权限的作用范围、预置的角色类型等，从而更好地管理集群的安全访问控制，满足企业用户细粒度的资源访问权限控制需求。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_ke_permission_demo = bytepluscc.vke.Permission("VKEPermissionDemo",
            role_domain="namespace",
            cluster_id="cd48m3cb1b2ba7l6ebgp0xxxxx",
            namespace="kube-public",
            role_name="vke:visitor",
            is_custom_role=False,
            grantee_id=59433888,
            grantee_type="User")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/permission:Permission example "permission_id"
        ```

        :param str resource_name: The name of the resource.
        :param PermissionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PermissionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorizer_id: Optional[pulumi.Input[builtins.int]] = None,
                 authorizer_type: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 grantee_id: Optional[pulumi.Input[builtins.int]] = None,
                 grantee_type: Optional[pulumi.Input[builtins.str]] = None,
                 is_custom_role: Optional[pulumi.Input[builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 role_domain: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PermissionArgs.__new__(PermissionArgs)

            __props__.__dict__["authorizer_id"] = authorizer_id
            __props__.__dict__["authorizer_type"] = authorizer_type
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["grantee_id"] = grantee_id
            __props__.__dict__["grantee_type"] = grantee_type
            __props__.__dict__["is_custom_role"] = is_custom_role
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["role_domain"] = role_domain
            __props__.__dict__["role_name"] = role_name
            __props__.__dict__["authorized_at"] = None
            __props__.__dict__["authorizer_name"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["kube_role_binding_name"] = None
            __props__.__dict__["message"] = None
            __props__.__dict__["permission_id"] = None
            __props__.__dict__["project_selector"] = None
            __props__.__dict__["revoked_at"] = None
            __props__.__dict__["status"] = None
        super(Permission, __self__).__init__(
            'bytepluscc:vke/permission:Permission',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authorized_at: Optional[pulumi.Input[builtins.str]] = None,
            authorizer_id: Optional[pulumi.Input[builtins.int]] = None,
            authorizer_name: Optional[pulumi.Input[builtins.str]] = None,
            authorizer_type: Optional[pulumi.Input[builtins.str]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            grantee_id: Optional[pulumi.Input[builtins.int]] = None,
            grantee_type: Optional[pulumi.Input[builtins.str]] = None,
            is_custom_role: Optional[pulumi.Input[builtins.bool]] = None,
            kube_role_binding_name: Optional[pulumi.Input[builtins.str]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            namespace: Optional[pulumi.Input[builtins.str]] = None,
            permission_id: Optional[pulumi.Input[builtins.str]] = None,
            project_selector: Optional[pulumi.Input[builtins.str]] = None,
            revoked_at: Optional[pulumi.Input[builtins.str]] = None,
            role_domain: Optional[pulumi.Input[builtins.str]] = None,
            role_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'Permission':
        """
        Get an existing Permission resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authorized_at: RBAC 权限策略资源被授权的时间。
        :param pulumi.Input[builtins.int] authorizer_id: 授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] authorizer_name: 授权者名称
        :param pulumi.Input[builtins.str] authorizer_type: 授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.str] cluster_id: 需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        :param pulumi.Input[builtins.str] created_time: RBAC 权限策略资源创建的时间。
        :param pulumi.Input[builtins.int] grantee_id: 被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        :param pulumi.Input[builtins.str] grantee_type: 被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        :param pulumi.Input[builtins.bool] is_custom_role: 给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        :param pulumi.Input[builtins.str] kube_role_binding_name: RBAC 权限策略资源在 Kubernetes 中的对象名称。
        :param pulumi.Input[builtins.str] message: 授权详细消息。
        :param pulumi.Input[builtins.str] namespace: 需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        :param pulumi.Input[builtins.str] permission_id: RBAC 权限策略资源 ID。
        :param pulumi.Input[builtins.str] project_selector: 项目选择器
        :param pulumi.Input[builtins.str] revoked_at: 撤销授权的时间。
        :param pulumi.Input[builtins.str] role_domain: 为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        :param pulumi.Input[builtins.str] role_name: 给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        :param pulumi.Input[builtins.str] status: RBAC 权限访问策略资源的状态，取值如下：Success：授权成功。Failed：授权失败。Pending：授权中。PartialSuccess：部分授权成功。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PermissionState.__new__(_PermissionState)

        __props__.__dict__["authorized_at"] = authorized_at
        __props__.__dict__["authorizer_id"] = authorizer_id
        __props__.__dict__["authorizer_name"] = authorizer_name
        __props__.__dict__["authorizer_type"] = authorizer_type
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["grantee_id"] = grantee_id
        __props__.__dict__["grantee_type"] = grantee_type
        __props__.__dict__["is_custom_role"] = is_custom_role
        __props__.__dict__["kube_role_binding_name"] = kube_role_binding_name
        __props__.__dict__["message"] = message
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["permission_id"] = permission_id
        __props__.__dict__["project_selector"] = project_selector
        __props__.__dict__["revoked_at"] = revoked_at
        __props__.__dict__["role_domain"] = role_domain
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["status"] = status
        return Permission(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authorizedAt")
    def authorized_at(self) -> pulumi.Output[builtins.str]:
        """
        RBAC 权限策略资源被授权的时间。
        """
        return pulumi.get(self, "authorized_at")

    @property
    @pulumi.getter(name="authorizerId")
    def authorizer_id(self) -> pulumi.Output[builtins.int]:
        """
        授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        """
        return pulumi.get(self, "authorizer_id")

    @property
    @pulumi.getter(name="authorizerName")
    def authorizer_name(self) -> pulumi.Output[builtins.str]:
        """
        授权者名称
        """
        return pulumi.get(self, "authorizer_name")

    @property
    @pulumi.getter(name="authorizerType")
    def authorizer_type(self) -> pulumi.Output[builtins.str]:
        """
        授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        """
        return pulumi.get(self, "authorizer_type")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        需要授权给 IAM 用户或角色的集群 ID。roleDomain为namespace或cluster时必须填写该参数值。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        RBAC 权限策略资源创建的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="granteeId")
    def grantee_id(self) -> pulumi.Output[builtins.int]:
        """
        被授权者的 ID。可以是 IAM 用户 ID，也可以是 IAM 角色 ID。
        """
        return pulumi.get(self, "grantee_id")

    @property
    @pulumi.getter(name="granteeType")
    def grantee_type(self) -> pulumi.Output[builtins.str]:
        """
        被授权者的类型，取值如下：User：IAM 用户。Role：IAM 角色。Account：账号。
        """
        return pulumi.get(self, "grantee_type")

    @property
    @pulumi.getter(name="isCustomRole")
    def is_custom_role(self) -> pulumi.Output[builtins.bool]:
        """
        给被授权者授予的 RBAC 角色是否为自定义角色，取值如下：true：自定义角色。false：（默认值）系统预置的角色。
        """
        return pulumi.get(self, "is_custom_role")

    @property
    @pulumi.getter(name="kubeRoleBindingName")
    def kube_role_binding_name(self) -> pulumi.Output[builtins.str]:
        """
        RBAC 权限策略资源在 Kubernetes 中的对象名称。
        """
        return pulumi.get(self, "kube_role_binding_name")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[builtins.str]:
        """
        授权详细消息。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[builtins.str]:
        """
        需要授权给 IAM 用户或角色的名空间名称。roleDomain等于namespace时必须填写该参数值。roleDomain不等于namespace时，填写该参数值不生效。
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="permissionId")
    def permission_id(self) -> pulumi.Output[builtins.str]:
        """
        RBAC 权限策略资源 ID。
        """
        return pulumi.get(self, "permission_id")

    @property
    @pulumi.getter(name="projectSelector")
    def project_selector(self) -> pulumi.Output[builtins.str]:
        """
        项目选择器
        """
        return pulumi.get(self, "project_selector")

    @property
    @pulumi.getter(name="revokedAt")
    def revoked_at(self) -> pulumi.Output[builtins.str]:
        """
        撤销授权的时间。
        """
        return pulumi.get(self, "revoked_at")

    @property
    @pulumi.getter(name="roleDomain")
    def role_domain(self) -> pulumi.Output[builtins.str]:
        """
        为 IAM 用户或角色授予的权限类型，取值如下：namespace：授予命名空间级别的权限。cluster：授予集群级别的权限。all_clusters：授予当前账号下全部集群级别的权限。
        """
        return pulumi.get(self, "role_domain")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[builtins.str]:
        """
        给被授权者授予的 RBAC 角色名称。目前必须填写该参数。当roleDomain为all_clusters时，不可以自定义角色名称。
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        RBAC 权限访问策略资源的状态，取值如下：Success：授权成功。Failed：授权失败。Pending：授权中。PartialSuccess：部分授权成功。
        """
        return pulumi.get(self, "status")

